==> af-runtime-2.9.6-sources.jar: com/af/v4/system/runtime/controller/V3FileController.java <==
package com.af.v4.system.runtime.controller;

import com.af.v4.system.common.core.service.ApplicationService;
import com.af.v4.system.common.file.utils.FilePathUtil;
import com.af.v4.system.common.jpa.service.EntityService;
import com.af.v4.system.common.jpa.service.SqlService;
import com.af.v4.system.common.jpa.utils.QueryParams;
import com.af.v4.system.common.plugins.core.CommonTools;
import com.af.v4.system.common.plugins.date.DateTools;
import jakarta.servlet.http.HttpServletRequest;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.servlet.ServletFileUpload;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;

/**
 * v3 上传文件请求兼容
 *
 * @author 张振宇
 * @apiNote 由于旧版 文件上传和 v4 toServer 差距较大，为了减少切换成本，此接口仅用于保持对v3及以前版本的兼容，
 * <p>该api随时都有可能移除，请不要使用该api开发任何新业务，仅对于以前的旧业务，
 */
@Deprecated(since = "1.0.0", forRemoval = true)
@RestController
@RequestMapping("/file")
public class V3FileController {

    private final FilePathUtil filePathUtil;
    private final EntityService entityService;
    private final SqlService sqlService;
    private final ApplicationService applicationService;


    public V3FileController(FilePathUtil filePathUtil, EntityService entityService, SqlService sqlService, ApplicationService applicationService) {
        this.filePathUtil = filePathUtil;
        this.entityService = entityService;
        this.sqlService = sqlService;
        this.applicationService = applicationService;
    }

    @PostMapping(value = "uploadFile")
    public String fileUpload2(HttpServletRequest request, @RequestParam("file") MultipartFile[] files) throws Exception {
        //  nacos 配置中的 resource
        //  resource:
        //   fileRootPath: D:/
        //   extraPaths: D:/
        String savePath = filePathUtil.getFileRootPathByServer() + File.separatorChar + applicationService.getApplicationName();
        JSONObject result = new JSONObject();
        File file = new File(savePath + File.separator + DateTools.getNow("yyyyMMdd"));
        //判断上传文件的保存目录是否存在
        if (!file.exists() && !file.isDirectory()) {
            file.mkdirs();
        }
        String downloadpath;
        //获取所有请求头参数
        Enumeration<String> headerNames = request.getHeaderNames();
        Map<String, Object> map = new HashMap<>();
        while (headerNames.hasMoreElements()) {
            String key = headerNames.nextElement();
            String value = URLDecoder.decode(request.getHeader(key), StandardCharsets.UTF_8);
            map.put(key.toLowerCase(), value);
        }
        DiskFileItemFactory factory = new DiskFileItemFactory();
        ServletFileUpload upload = new ServletFileUpload(factory);
        upload.setHeaderEncoding("UTF-8");
        if (files.length == 0) {
            return "";
        }
        for (MultipartFile item : files) {
            //获得文件名
            String filename = item.getOriginalFilename();
            if (!validateFileName(filename)) {
                result.put("result", "文件不符合规范");
                return result.toString();
            }
            filename = filename.substring(0, filename.lastIndexOf('.')) + "_" + map.get("username") + "_" + CommonTools.getUUID(true) + "." + filename.substring(filename.lastIndexOf('.') + 1);
            //获取item中的上传文件的输入流
            try (InputStream in = item.getInputStream();
                 FileOutputStream out = new FileOutputStream(file.getAbsolutePath() + File.separator + filename)) {
                //创建一个缓冲区
                byte[] buffer = new byte[1024];
                //判断输入流中的数据是否已经读完的标识
                int len;
                //循环将输入流读入到缓冲区当中，(len=in.read(buffer))>0就表示in里面还有数据
                while ((len = in.read(buffer)) > 0) {
                    //使用FileOutputStream输出流将缓冲区的数据写入到指定的目录(savePath + "\\" + filename)当中
                    out.write(buffer, 0, len);
                }
            }
            String filetype = filename.substring(filename.lastIndexOf('.') + 1);
            if (map.get("blodid") != null && !((String) map.get("blodid")).trim().isEmpty()) {
                //存f_userinfo_id
                map.put("f_blobid", map.get("blodid"));
            }
            if (map.containsKey("businessid")) {
                //存业务id
                if (map.get("businessid") != null && !((String) map.get("businessid")).trim().isEmpty()) {
                    map.put("f_businessid", map.get("businessid"));
                }
            }
            if (map.get("username") != null && !((String) map.get("username")).trim().isEmpty()) {
                map.put("f_username", map.get("username"));
            }
            downloadpath = filePathUtil.getFileDownloadUrlByServer(filetype, filename);
            map.put("f_filename", filename);
            map.put("f_filetype", filetype);
            map.put("f_downloadpath", downloadpath);
            map.put("path", downloadpath);
            map.put("f_realpath", savePath);
            map.remove("id");
            JSONObject JObj = entityService.partialSave("t_files", new JSONObject(map));
            map.put("id", JObj.get("id"));
            result = new JSONObject(map);
        }
        result.put("result", "success");
        return result.toString();
    }

    // 获得图片
    @GetMapping(value = "getfile/{id}")
    public byte[] getfile(@PathVariable("id") String id) {
        try {
            // 获取文件真实路径
            JSONArray array = sqlService.querySQL(
                    "getFileById",
                    "select f_downloadpath from t_files where id = :id",
                    new QueryParams.Builder().addParameter("id", id).build()
            );
            if (array.isEmpty()) {
                return null;
            }
            JSONObject map = array.getJSONObject(0);
            // 获得文件名
            String filename = map.getString("f_downloadpath");
            // 获得文件
            File file = new File(filename);
            try (FileInputStream in = new FileInputStream(file)) {
                byte[] result = new byte[(int) file.length()];
                in.read(result);
                return result;
            }
        } catch (RuntimeException e) {
            throw e;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 通过filepath获取文件
     */
    @PostMapping(value = "getUploadFile")
    public byte[] getFileOfFilePath(String values) {
        try {
            // 获得文件
            values = values.replaceAll("\\\\", "/");
            JSONObject params = new JSONObject(values);
            Object object = params.get("filepath");
            String filepath = (String) object;
            File file = new File(filepath);
            try (FileInputStream in = new FileInputStream(file)) {
                byte[] result = new byte[(int) file.length()];
                in.read(result);
                return result;
            }
        } catch (RuntimeException e) {
            throw e;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    private String getSuffix(String name) {
        return name.split("\\.")[name.split("\\.").length - 1];
    }


    private boolean validateFileName(String name) {
        if (name == null || name.isEmpty()) {
            return false;
        }
        String[] uploadType = {"doc", "docx", "xls", "xlsx", "jpg", "png", "gif", "bmp", "avi", "mp4", "wmv", "rmvb", "mov", "pdf", "dwg", "txt"};
        String suffix = getSuffix(name).toLowerCase();
        return Arrays.asList(uploadType).contains(suffix);
    }
}

==> af-runtime-2.9.24-sources.jar: com/af/v4/system/runtime/controller/V3FileController.java <==
package com.af.v4.system.runtime.controller;

import com.af.v4.system.common.file.utils.FilePathUtil;
import com.af.v4.system.common.jpa.service.EntityService;
import com.af.v4.system.common.jpa.service.SqlService;
import com.af.v4.system.common.jpa.utils.QueryParams;
import com.af.v4.system.common.plugins.core.CommonTools;
import jakarta.servlet.http.HttpServletRequest;
import org.json.JSONArray;
import org.json.JSONObject;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Map;

import static com.af.v4.system.common.core.constant.FileConstants.RESOURCE_EXT_2_TYPE;

/**
 * v3 上传文件请求兼容
 *
 * @author 张振宇
 * @apiNote 由于旧版 文件上传和 v4 toServer 差距较大，为了减少切换成本，此接口仅用于保持对v3及以前版本的兼容，
 * <p>该api随时都有可能移除，请不要使用该api开发任何新业务，仅对于以前的旧业务，
 */
@Deprecated
@RestController
@RequestMapping("/file")
public class V3FileController {

    private final FilePathUtil filePathUtil;
    private final EntityService entityService;
    private final SqlService sqlService;


    public V3FileController(FilePathUtil filePathUtil, EntityService entityService, SqlService sqlService) {
        this.filePathUtil = filePathUtil;
        this.entityService = entityService;
        this.sqlService = sqlService;
    }

    @PostMapping(value = "uploadFile")
    public String fileUpload2(HttpServletRequest request, @RequestParam("file") MultipartFile[] files) throws Exception {
        JSONObject result = new JSONObject();
        if (files.length == 0) {
            return "";
        }

        // 获取并解码请求头参数
        Map<String, Object> map = new HashMap<>();
        Enumeration<String> headerNames = request.getHeaderNames();
        while (headerNames.hasMoreElements()) {
            String key = headerNames.nextElement();
            String value = URLDecoder.decode(request.getHeader(key), StandardCharsets.UTF_8);
            map.put(key.toLowerCase(), value);
        }

        for (MultipartFile item : files) {
            String filename = item.getOriginalFilename();
            if (!validateFileName(filename)) {
                return new JSONObject().put("result", "文件不符合规范").toString();
            }

            // 构建新文件名
            String fileNameWithoutExt = filename.substring(0, filename.lastIndexOf('.'));
            String extension = filename.substring(filename.lastIndexOf('.') + 1);
            filename = fileNameWithoutExt + "_" + map.get("username") + "_" + CommonTools.getUUID(true) + "." + extension;

            String savePath = filePathUtil.getFileFullPathByServer(RESOURCE_EXT_2_TYPE.get(extension), filename);
            // 确保目标文件夹存在
            File saveDir = new File(savePath).getParentFile();
            if (!saveDir.exists()) {
                saveDir.mkdirs();
            }
            try (InputStream in = item.getInputStream();
                 FileOutputStream out = new FileOutputStream(savePath)) {
                in.transferTo(out);
            }

            // 更新文件相关信息
            if (map.get("blodid") != null && !((String) map.get("blodid")).trim().isEmpty()) {
                map.put("f_blobid", map.get("blodid"));
            }
            if (map.get("f_table_name") != null && !((String) map.get("f_table_name")).trim().isEmpty()) {
                map.put("f_table_name", map.get("f_table_name"));
            }
            if (map.containsKey("businessid") && map.get("businessid") != null &&
                    !((String) map.get("businessid")).trim().isEmpty()) {
                map.put("f_businessid", map.get("businessid"));
            }
            if (map.get("username") != null && !((String) map.get("username")).trim().isEmpty()) {
                map.put("f_username", map.get("username"));
            }

            String downloadpath = filePathUtil.getFileDownloadUrlByServer(RESOURCE_EXT_2_TYPE.get(extension), filename);
            map.put("f_filename", filename);
            map.put("f_filetype", extension);
            map.put("f_downloadpath", downloadpath);
            map.put("path", downloadpath);
            map.put("f_realpath", savePath);

            // 保存到数据库
            map.remove("id");
            JSONObject savedObj = entityService.partialSave("t_files", new JSONObject(map));
            map.put("id", savedObj.get("id"));
            result = new JSONObject(map);
        }

        return result.put("result", "success").toString();
    }

    // 获得图片
    @GetMapping(value = "getfile/{id}")
    public byte[] getfile(@PathVariable("id") String id) {
        try {
            // 获取文件真实路径
            JSONArray array = sqlService.querySQL(
                    "getFileById",
                    "select f_downloadpath from t_files where id = :id",
                    new QueryParams.Builder().addParameter("id", id).build()
            );
            if (array.isEmpty()) {
                return null;
            }
            JSONObject map = array.getJSONObject(0);
            // 获得文件名
            String filename = map.getString("f_downloadpath");
            // 获得文件
            File file = new File(filename);
            try (FileInputStream in = new FileInputStream(file)) {
                byte[] result = new byte[(int) file.length()];
                in.read(result);
                return result;
            }
        } catch (RuntimeException e) {
            throw e;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 通过filepath获取文件
     */
    @PostMapping(value = "getUploadFile")
    public byte[] getFileOfFilePath(String values) {
        try {
            // 获得文件
            values = values.replaceAll("\\\\", "/");
            JSONObject params = new JSONObject(values);
            Object object = params.get("filepath");
            String filepath = (String) object;
            File file = new File(filepath);
            try (FileInputStream in = new FileInputStream(file)) {
                byte[] result = new byte[(int) file.length()];
                in.read(result);
                return result;
            }
        } catch (RuntimeException e) {
            throw e;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    private String getSuffix(String name) {
        return name.split("\\.")[name.split("\\.").length - 1];
    }


    private boolean validateFileName(String name) {
        if (name == null || name.isEmpty()) {
            return false;
        }
        String suffix = getSuffix(name).toLowerCase();
        return RESOURCE_EXT_2_TYPE.containsKey(suffix);
    }
}
